==> localnews-admin-api-3.0.1-20191106.031037-1-sources.jar: com/bxm/localnews/admin/controller/base/AdminAreaController.java <==
package com.bxm.localnews.admin.controller.base;

import com.bxm.localnews.admin.dto.AreaDivisionDTO;
import com.bxm.localnews.admin.dto.AreaInfoDTO;
import com.bxm.localnews.admin.dto.LocationDTO;
import com.bxm.localnews.admin.dto.LocationInfoDTO;
import com.bxm.localnews.admin.param.AreaInfoParam;
import com.bxm.localnews.admin.param.AreaInfoQueryParam;
import com.bxm.localnews.admin.param.LocationParam;
import com.bxm.localnews.admin.service.base.AreaDivisionService;
import com.bxm.localnews.admin.service.base.AreaInfoService;
import com.bxm.localnews.admin.service.base.LocationService;
import com.bxm.localnews.admin.vo.AreaInfo;
import com.bxm.localnews.common.util.ResultUtil;
import com.bxm.localnews.common.vo.Json;
import com.bxm.newidea.component.controller.BaseController;
import com.bxm.newidea.component.vo.PageWarper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.List;

@Api(tags = "1-03 [管理]地区管理", description = "地区管理的相关操作")
@RestController
@RequestMapping("api/admin/area")
public class AdminAreaController extends BaseController {

    private LocationService locationService;

    private AreaDivisionService areaDivisionService;

    private AreaInfoService areaInfoService;

    @Autowired
    public AdminAreaController(LocationService locationService,
                               AreaDivisionService areaDivisionService,
                               AreaInfoService areaInfoService) {
        this.locationService = locationService;
        this.areaDivisionService = areaDivisionService;
        this.areaInfoService = areaInfoService;
    }

    @GetMapping(value = "/list")
    @ApiOperation(value = "1-03-01 获取所有可开通和已开通城市")
    public Json<List<LocationDTO>> listLocation(@Valid LocationParam locationParam) {
        return ResultUtil.genSuccessResult(locationService.listLocation(locationParam));
    }

    @PostMapping(value = "/{code}/hot")
    @ApiOperation(value = "1-03-02 设置为热门城市", notes = "把城市设为热门城市，使之在客户端以列表形式展现")
    public Json saveHotLocation(@PathVariable String code) {
        locationService.saveHotLocation(code);
        return ResultUtil.genSuccessResult();
    }

    @PostMapping(value = "/{code}/opened")
    @ApiOperation(value = "1-03-03 设置为已开通城市", notes = "把城市设为已开通城市，使之在客户端以列表形式展现")
    public Json saveOpenedLocation(@PathVariable String code) {
        locationService.saveOpenedLocation(code);
        return ResultUtil.genSuccessResult();
    }

    @GetMapping(value = "/{code}/list")
    @ApiOperation(value = "1-03-04 获取省下所有已开通城市", notes = "在地址联动选择时，在下方显示该城市下的已开通地区")
    public Json<List<LocationDTO>> listLocation(@PathVariable String code) {
        return ResultUtil.genSuccessResult(locationService.listOpenedLocationByAreaWithTwoLevels(code, (byte) 1));
    }

    @GetMapping(value = "/province/{code}/list")
    @ApiOperation(value = "1-03-05 仅获取省份所有已开通或可开通城市", notes = "在地址联动选择时，在下方显示该城市下的已开通或可开通地区")
    public Json<List<LocationDTO>> listProvinceLocation(@PathVariable String code) {
        return ResultUtil.genSuccessResult(locationService.listOpenedLocationByAreaWithTwoLevels(code, null));
    }

    @GetMapping(value = "/info/list")
    @ApiOperation(value = "1-03-06 后台区域管理-获取所有地域信息", notes = "包含覆盖率和传播率")
    public Json<PageWarper<AreaInfo>> listAreaInfo(AreaInfoQueryParam areaInfoParam) {
        return ResultUtil.genSuccessResult(areaInfoService.queryPages(areaInfoParam));
    }

    @PostMapping(value = "/info/add")
    @ApiOperation(value = "1-03-07 后台区域管理-新增地域信息")
    public Json saveAreaInfo(@RequestBody AreaInfoParam areaInfoParam) {
        return Json.build(areaInfoService.saveAreaInfo(areaInfoParam));
    }

    @PostMapping(value = "/info/modify")
    @ApiOperation(value = "1-03-08 后台区域管理-根据code修改地域信息")
    public Json modifyAreaInfo(@RequestBody AreaInfoParam areaInfoParam) {
        int flag = areaInfoService.updateAreaInfo(areaInfoParam);
        if (flag > 0) {
            return ResultUtil.genSuccessMsg("更新成功");
        }
        return ResultUtil.genFailedResult("更新失败");

    }

    @PostMapping(value = "/info/del/{code}")
    @ApiOperation(value = "1-03-09 后台区域管理-根据code删除地域信息")
    @ApiImplicitParam(name = "code", value = "地区编码", required = true)
    public Json delAreaInfo(@PathVariable String code) {
        int flag = areaInfoService.delAreaInfo(code);
        if (flag > 0) {
            return ResultUtil.genSuccessMsg("更新成功");
        }
        return ResultUtil.genFailedResult("更新失败");
    }


    @GetMapping(value = "/division/{parentCode}")
    @ApiOperation(value = "1-03-10 根据上级编码获取省市区县街道", notes = "如果parentCode为0,则返回最上层的省份信息")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "parentCode", value = "父级编号"),
    })
    public Json<List<AreaDivisionDTO>> listAreaDivision(@PathVariable String parentCode) {
        return ResultUtil.genSuccessResult(areaDivisionService.listAreaDivisionDTO(parentCode));
    }

    @GetMapping(value = "/info/detail/{code}")
    @ApiOperation(value = "1-03-11 后台区域管理-根据code得到地域的详细信息")
    @ApiImplicitParam(name = "code", value = "地区编码", required = true)
    public Json<AreaInfoDTO> getAreaDetail(@PathVariable String code) {
        return ResultUtil.genSuccessResult(areaInfoService.getAreaInfo(code));
    }


    @GetMapping(value = "/city/{code}/list")
    @ApiOperation(value = "1-03-12 根据市级信息获取市下的所有已开通区域")
    @ApiImplicitParam(name = "code", value = "地区编码", required = true)
    public Json<List<LocationDTO>> listCityLocation(@PathVariable String code) {
        List<LocationDTO> locationDTOList = locationService.listOpenedLocationByArea(code, (byte) 1);
        return ResultUtil.genSuccessResult(locationDTOList);
    }

    @PostMapping(value = "/communityContent/modify")
    @ApiOperation(value = "1-03-13 更新社区内容配置")
    public Json modifyCommunityContent(@RequestBody AreaInfoParam areaInfoParam) {

        try {

            int flag = areaInfoService.updateCommunityContent(areaInfoParam);
            if (flag > 0) {
                return ResultUtil.genSuccessMsg("更新成功");
            }
            return ResultUtil.genFailedResult("更新失败");
        } catch (Exception e) {
            logger.error("更新社区内容异常", e);
            return ResultUtil.genFailedResult("更新异常");
        }

    }

    @PostMapping(value = "/customerService/modify")
    @ApiOperation(value = "1-03-14 更新客服小助手")
    public Json modifyCustomerService(@RequestBody AreaInfoParam areaInfoParam) {


        try {
            int flag = areaInfoService.updateCustomerService(areaInfoParam);
            if (flag > 0) {
                return ResultUtil.genSuccessMsg("更新成功");
            }
            return ResultUtil.genFailedResult("更新失败");
        } catch (Exception e) {
            logger.error("更新客服小助手异常", e);
            return ResultUtil.genFailedResult("更新客服小助手异常");
        }

    }

    @PostMapping(value = "/indexPublish/modify")
    @ApiOperation(value = "1-03-15 更新首页发帖入口")
    public Json modifyIndexPublish(@RequestBody AreaInfoParam areaInfoParam) {
        try {
            int flag = areaInfoService.updateIndexPublish(areaInfoParam);
            if (flag > 0) {
                return ResultUtil.genSuccessMsg("更新成功");
            }
            return ResultUtil.genFailedResult("更新失败");
        } catch (Exception e) {
            logger.error("更新首页发帖入口异常", e);
            return ResultUtil.genFailedResult("更新首页发帖入口异常");
        }

    }

    @GetMapping(value = "/location/detail/{code}")
    @ApiOperation(value = "1-03-16 获取详情-首页发帖入口,客服小助手，社区内容配置")
    @ApiImplicitParam(name = "code", value = "地区编码", required = true)
    public Json<LocationInfoDTO> getLocationDetail(@PathVariable String code) {
        try {
            LocationInfoDTO locationInfoDTO = areaInfoService.getLocationInfo(code);
            if (null == locationInfoDTO) {
                return ResultUtil.genFailedResult("获取详情失败");
            }
            return ResultUtil.genSuccessResult(areaInfoService.getLocationInfo(code));
        } catch (Exception e) {
            logger.error("获取详情异常", e);
            return ResultUtil.genFailedResult("获取详情异常");
        }
    }

    @GetMapping(value = "/location/detail/hotCity")
    @ApiOperation(value = "1-03-17 获得热门城市")
    public Json<List<LocationDTO>> getHotCity() {
        List<LocationDTO>  hotCitys= areaInfoService.getHotCity();
        return ResultUtil.genSuccessResult(hotCitys);
    }

}

==> localnews-admin-api-3.11.0-sources.jar: com/bxm/localnews/admin/controller/base/AdminAreaController.java <==
package com.bxm.localnews.admin.controller.base;

import com.bxm.localnews.admin.dto.AreaDivisionDTO;
import com.bxm.localnews.admin.dto.AreaInfoDTO;
import com.bxm.localnews.admin.dto.LocationDTO;
import com.bxm.localnews.admin.dto.LocationInfoDTO;
import com.bxm.localnews.admin.param.*;
import com.bxm.localnews.admin.service.base.AreaDivisionService;
import com.bxm.localnews.admin.service.base.AreaInfoService;
import com.bxm.localnews.admin.service.base.LocationService;
import com.bxm.localnews.admin.vo.AreaInfo;
import com.bxm.localnews.admin.vo.LocationOfficialAccountVO;
import com.bxm.localnews.admin.vo.LocationPhoneVO;
import com.bxm.localnews.admin.vo.LocationRelationBean;
import com.bxm.localnews.common.util.ResultUtil;
import com.bxm.localnews.common.vo.Json;
import com.bxm.newidea.component.controller.BaseController;
import com.bxm.newidea.component.vo.Message;
import com.bxm.newidea.component.vo.PageWarper;
import com.bxm.newidea.component.vo.ResponseJson;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@Api(tags = "1-03 [管理]地区管理", description = "地区管理的相关操作")
@RestController
@RequestMapping("api/admin/area")
public class AdminAreaController extends BaseController {

    private LocationService locationService;

    private AreaDivisionService areaDivisionService;

    private AreaInfoService areaInfoService;

    @Autowired
    public AdminAreaController(LocationService locationService,
                               AreaDivisionService areaDivisionService,
                               AreaInfoService areaInfoService) {
        this.locationService = locationService;
        this.areaDivisionService = areaDivisionService;
        this.areaInfoService = areaInfoService;
    }

    @GetMapping(value = "/list")
    @ApiOperation(value = "1-03-01 获取所有可开通和已开通城市")
    public Json<List<LocationDTO>> listLocation(@Valid LocationParam locationParam) {
        return ResultUtil.genSuccessResult(locationService.listLocation(locationParam));
    }

    @PostMapping(value = "/{code}/hot")
    @ApiOperation(value = "1-03-02 设置为热门城市", notes = "把城市设为热门城市，使之在客户端以列表形式展现")
    public Json saveHotLocation(@PathVariable String code) {
        locationService.saveHotLocation(code);
        return ResultUtil.genSuccessResult();
    }

    @PostMapping(value = "/{code}/opened")
    @ApiOperation(value = "1-03-03 设置为已开通城市", notes = "把城市设为已开通城市，使之在客户端以列表形式展现")
    public Json saveOpenedLocation(@PathVariable String code) {
        locationService.saveOpenedLocation(code);
        return ResultUtil.genSuccessResult();
    }

    @GetMapping(value = "/{code}/list")
    @ApiOperation(value = "1-03-04 获取省下所有已开通城市", notes = "在地址联动选择时，在下方显示该城市下的已开通地区")
    public Json<List<LocationDTO>> listLocation(@PathVariable String code) {
        return ResultUtil.genSuccessResult(locationService.listOpenedLocationByAreaWithTwoLevels(code, (byte) 1));
    }

    @GetMapping(value = "/province/{code}/list")
    @ApiOperation(value = "1-03-05 仅获取省份所有已开通或可开通城市", notes = "在地址联动选择时，在下方显示该城市下的已开通或可开通地区")
    public Json<List<LocationDTO>> listProvinceLocation(@PathVariable String code) {
        return ResultUtil.genSuccessResult(locationService.listOpenedLocationByAreaWithTwoLevels(code, null));
    }

    @GetMapping(value = "/info/list")
    @ApiOperation(value = "1-03-06 后台区域管理-获取所有地域信息", notes = "包含覆盖率和传播率")
    public Json<PageWarper<AreaInfo>> listAreaInfo(AreaInfoQueryParam areaInfoParam) {
        return ResultUtil.genSuccessResult(areaInfoService.queryPages(areaInfoParam));
    }

    @PostMapping(value = "/info/add")
    @ApiOperation(value = "1-03-07 后台区域管理-新增地域信息")
    public Json saveAreaInfo(@RequestBody AreaInfoParam areaInfoParam) {
        return Json.build(areaInfoService.saveAreaInfo(areaInfoParam));
    }

    @PostMapping(value = "/info/modify")
    @ApiOperation(value = "1-03-08 后台区域管理-根据code修改地域信息")
    public Json modifyAreaInfo(@RequestBody AreaInfoParam areaInfoParam) {
        int flag = areaInfoService.updateAreaInfo(areaInfoParam);
        if (flag > 0) {
            return ResultUtil.genSuccessMsg("更新成功");
        }
        return ResultUtil.genFailedResult("更新失败");

    }

    @PostMapping(value = "/info/del/{code}")
    @ApiOperation(value = "1-03-09 后台区域管理-根据code删除地域信息")
    @ApiImplicitParam(name = "code", value = "地区编码", required = true)
    public Json delAreaInfo(@PathVariable String code) {
        int flag = areaInfoService.delAreaInfo(code);
        if (flag > 0) {
            return ResultUtil.genSuccessMsg("更新成功");
        }
        return ResultUtil.genFailedResult("更新失败");
    }


    @GetMapping(value = "/division/{parentCode}")
    @ApiOperation(value = "1-03-10 根据上级编码获取省市区县街道", notes = "如果parentCode为0,则返回最上层的省份信息")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path", name = "parentCode", value = "父级编号"),
    })
    public Json<List<AreaDivisionDTO>> listAreaDivision(@PathVariable String parentCode) {
        return ResultUtil.genSuccessResult(areaDivisionService.listAreaDivisionDTO(parentCode));
    }

    @GetMapping(value = "/info/detail/{code}")
    @ApiOperation(value = "1-03-11 后台区域管理-根据code得到地域的详细信息")
    @ApiImplicitParam(name = "code", value = "地区编码", required = true)
    public Json<AreaInfoDTO> getAreaDetail(@PathVariable String code) {
        return ResultUtil.genSuccessResult(areaInfoService.getAreaInfo(code));
    }


    @GetMapping(value = "/city/{code}/list")
    @ApiOperation(value = "1-03-12 根据市级信息获取市下的所有已开通区域")
    @ApiImplicitParam(name = "code", value = "地区编码", required = true)
    public Json<List<LocationDTO>> listCityLocation(@PathVariable String code) {
        List<LocationDTO> locationDTOList = locationService.listOpenedLocationByArea(code, (byte) 1);
        return ResultUtil.genSuccessResult(locationDTOList);
    }

    @PostMapping(value = "/communityContent/modify")
    @ApiOperation(value = "1-03-13 更新社区内容配置")
    public Json modifyCommunityContent(@RequestBody AreaInfoParam areaInfoParam) {

        try {

            int flag = areaInfoService.updateCommunityContent(areaInfoParam);
            if (flag > 0) {
                return ResultUtil.genSuccessMsg("更新成功");
            }
            return ResultUtil.genFailedResult("更新失败");
        } catch (Exception e) {
            logger.error("更新社区内容异常", e);
            return ResultUtil.genFailedResult("更新异常");
        }

    }

    @PostMapping(value = "/customerService/modify")
    @ApiOperation(value = "1-03-14 更新客服小助手")
    public Json modifyCustomerService(@RequestBody AreaInfoParam areaInfoParam) {


        try {
            int flag = areaInfoService.updateCustomerService(areaInfoParam);
            if (flag > 0) {
                return ResultUtil.genSuccessMsg("更新成功");
            }
            return ResultUtil.genFailedResult("更新失败");
        } catch (Exception e) {
            logger.error("更新客服小助手异常", e);
            return ResultUtil.genFailedResult("更新客服小助手异常");
        }

    }

    @PostMapping(value = "/indexPublish/modify")
    @ApiOperation(value = "1-03-15 更新首页发帖入口")
    public Json modifyIndexPublish(@RequestBody AreaInfoParam areaInfoParam) {
        try {
            int flag = areaInfoService.updateIndexPublish(areaInfoParam);
            if (flag > 0) {
                return ResultUtil.genSuccessMsg("更新成功");
            }
            return ResultUtil.genFailedResult("更新失败");
        } catch (Exception e) {
            logger.error("更新首页发帖入口异常", e);
            return ResultUtil.genFailedResult("更新首页发帖入口异常");
        }

    }

    @GetMapping(value = "/location/detail/{code}")
    @ApiOperation(value = "1-03-16 获取详情-首页发帖入口,客服小助手，社区内容配置")
    @ApiImplicitParam(name = "code", value = "地区编码", required = true)
    public Json<LocationInfoDTO> getLocationDetail(@PathVariable String code) {
        try {
            LocationInfoDTO locationInfoDTO = areaInfoService.getLocationInfo(code);
            if (null == locationInfoDTO) {
                return ResultUtil.genFailedResult("获取详情失败");
            }
            return ResultUtil.genSuccessResult(areaInfoService.getLocationInfo(code));
        } catch (Exception e) {
            logger.error("获取详情异常", e);
            return ResultUtil.genFailedResult("获取详情异常");
        }
    }

    @GetMapping(value = "/location/detail/hotCity")
    @ApiOperation(value = "1-03-17 获得热门城市")
    public Json<List<LocationDTO>> getHotCity() {
        List<LocationDTO> hotCitys = areaInfoService.getHotCity();
        return ResultUtil.genSuccessResult(hotCitys);
    }

    @GetMapping(value = "/location/vipdetail/{code}")
    @ApiOperation(value = "1-03-18 获取详情-VIP分享文案配置")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "code", value = "地区编码", required = true),
            @ApiImplicitParam(name = "type", value = "类型：3-VIP分享文案配置")
    })
    public Json<List<LocationRelationBean>> getLocationVipDetail(@PathVariable String code, @RequestParam("type") Integer type) {
        try {
            return ResultUtil.genSuccessResult(areaInfoService.getDetailByCodeType(code, type));
        } catch (Exception e) {
            logger.error("获取详情异常", e);
            return ResultUtil.genFailedResult("获取详情异常");
        }
    }

    @PostMapping(value = "/location/vipinsert")
    @ApiOperation(value = "1-03-19 新增VIP分享文案配置")
    public Json<Boolean> locationVipInsert(@RequestBody LocationRelationParam param) {
        try {
            return ResultUtil.genSuccessResult(locationService.saveLocationRelation(param));
        } catch (Exception e) {
            logger.error("获取详情异常", e);
            return ResultUtil.genFailedResult("获取详情异常");
        }
    }

    @PostMapping(value = "/location/vipupdate")
    @ApiOperation(value = "1-03-20 修改-VIP分享文案配置")
    public Json<Boolean> getLocationVipDetail(@RequestBody LocationRelationParam param) {
        try {
            return ResultUtil.genSuccessResult(locationService.updateLocationRelation(param));
        } catch (Exception e) {
            logger.error("获取详情异常", e);
            return ResultUtil.genFailedResult("获取详情异常");
        }
    }

    @PostMapping(value = "/location/phone/update")
    @ApiOperation(value = "1-03-21 修改团购客服电话")
    public Json<Boolean> updateLocationPhone(@RequestBody AreaCustomerPhoneParam param) {
        try {
            return ResultUtil.genSuccessResult(locationService.updateLocationPhone(param));
        } catch (Exception e) {
            logger.error("获取详情异常", e);
            return ResultUtil.genFailedResult("获取详情异常");
        }
    }

    @GetMapping(value = "/location/phone/get")
    @ApiOperation(value = "1-03-22 获取团购客服电话")
    public Json<LocationPhoneVO> getLocationPhone(@RequestParam("code") String code) {
        try {
            return ResultUtil.genSuccessResult(locationService.getLocationPhoneByCode(code));
        } catch (Exception e) {
            logger.error("获取详情异常", e);
            return ResultUtil.genFailedResult("获取详情异常");
        }
    }

    @PostMapping(value = "/location/officialAccount/update")
    @ApiOperation(value = "1-03-23 修改微信公众号二维码图片")
    public ResponseJson<Boolean> updateLocationOfficialAccount(@RequestBody AreaOfficialAccountParam param) {
        try {
            Message message = locationService.updateOfficialAccount(param);
            if (!message.isSuccess()) {
                return ResponseJson.build(message);
            }
            return ResponseJson.ok(true);
        } catch (Exception e) {
            logger.error("获取详情异常", e);
            return ResponseJson.build(Message.build(false).setMessage("修改微信公众号二维码图片异常"));
        }
    }

    @GetMapping(value = "/location/officialAccount/get")
    @ApiOperation(value = "1-03-24 获取微信公众号二维码图片")
    public ResponseJson<LocationOfficialAccountVO> getLocationOfficialAccount(@RequestParam("code") String code) {
        try {
            return ResponseJson.ok(locationService.getOfficialAccountByCode(code));
        } catch (Exception e) {
            logger.error("获取详情异常", e);
            return ResponseJson.build(Message.build(false).setMessage("获取详情异常"));
        }
    }
}
